@@ -1,5 +1,5 @@
-from .auth import AuthenticatorMixin
-from .handler import HandlerMixin
+from .auth import AuthMixin
 from .emitter import EmitterMixin
 from .parser import ParserMixin
+from .handler import HandlerMixin
 from .throttle import ThrottleMixin
